==> glob2_0.8.14.orig.tar.gz: glob2-0.8.14/src/MultiplayersHostScreen.h <==
/*
  Copyright (C) 2001-2004 Stephane Magnenat & Luc-Olivier de Charrière
  for any question or comment contact us at nct@ysagoon.com or nuage@ysagoon.com

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/

#ifndef __MULTIPLAYERHOSTSCREEN_H
#define __MULTIPLAYERHOSTSCREEN_H

#include <vector>
#include <GUIBase.h>
using namespace GAGGUI;

namespace GAGGUI
{
	class Text;
	class TextArea;
	class TextInput;
	class TextButton;
	class ColorButton;
}
class SessionInfo;
class MultiplayersHost;
class MultiplayersJoin;

class MultiplayersHostScreen: public Screen
{
public:
	enum
	{
		START = 1,
		CANCEL = 2,
		STARTED=11,
		
		COLOR_BUTTONS=32,
		CLOSE_BUTTONS=64,
		
		ADD_AI = 100
	};

	enum { MAX_NUMBER_OF_PLAYERS = 16};

private:
	int timeCounter;
	int executionMode;

public:
	MultiplayersHostScreen(SessionInfo *sessionInfo, bool shareOnYOG);
	virtual ~MultiplayersHostScreen();

	void onTimer(Uint32 tick);
	void onAction(Widget *source, Action action, int par1, int par2);

	MultiplayersHost *multiplayersHost;
	MultiplayersJoin *multiplayersJoin;
	bool shareOnYOG;

	TextButton *startButton;
	std::vector<TextButton *> addAI;
	ColorButton *color[MAX_NUMBER_OF_PLAYERS];
	Text *text[MAX_NUMBER_OF_PLAYERS];
	TextButton *kickButton[MAX_NUMBER_OF_PLAYERS];
	Text *startTimer;

	TextInput *textInput;
	TextArea *chatWindow;

	bool wasSlotUsed[MAX_NUMBER_OF_PLAYERS];
	Text *notReadyText;
	Text *gameFullText;

	SessionInfo *savedSessionInfo;
};

#endif

==> glob2_0.8.21.orig.tar.gz: glob2-0.8.21/src/MultiplayersHostScreen.h <==
/*
  Copyright (C) 2001-2004 Stephane Magnenat & Luc-Olivier de Charrière
  for any question or comment contact us at nct@ysagoon.com or nuage@ysagoon.com

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/

#ifndef __MULTIPLAYERHOSTSCREEN_H
#define __MULTIPLAYERHOSTSCREEN_H

#include <vector>
#include "Glob2Screen.h"

namespace GAGGUI
{
	class Text;
	class TextArea;
	class TextInput;
	class TextButton;
	class ColorButton;
}
class SessionInfo;
class MultiplayersHost;
class MultiplayersJoin;

class MultiplayersHostScreen : public Glob2Screen
{
public:
	enum
	{
		START = 1,
		CANCEL = 2,
		STARTED=11,
		
		COLOR_BUTTONS=32,
		CLOSE_BUTTONS=64,
		
		ADD_AI = 100
	};

	enum { MAX_NUMBER_OF_PLAYERS = 16};

private:
	int timeCounter;
	int executionMode;

public:
	MultiplayersHostScreen(SessionInfo *sessionInfo, bool shareOnYOG);
	virtual ~MultiplayersHostScreen();

	void onTimer(Uint32 tick);
	void onAction(Widget *source, Action action, int par1, int par2);

	MultiplayersHost *multiplayersHost;
	MultiplayersJoin *multiplayersJoin;
	bool shareOnYOG;

	TextButton *startButton;
	std::vector<TextButton *> addAI;
	ColorButton *color[MAX_NUMBER_OF_PLAYERS];
	Text *text[MAX_NUMBER_OF_PLAYERS];
	TextButton *kickButton[MAX_NUMBER_OF_PLAYERS];
	Text *startTimer;

	TextInput *textInput;
	TextArea *chatWindow;

	bool wasSlotUsed[MAX_NUMBER_OF_PLAYERS];
	Text *notReadyText;
	Text *gameFullText;

	SessionInfo *savedSessionInfo;
};

#endif
